pub type ForceReservations<T> = StorageValue<_GeneratedPrefixForStorageForceReservations<T>, ReservationsRecordOf<T>, ValueQuery>;Expand description
Force reservations that need to be inserted into the workplan at the next sale rotation.
They are automatically freed at the next sale rotation.
Storage type is [StorageValue] with value type ReservationsRecordOf < T >.
Aliased Type
pub struct ForceReservations<T>(/* private fields */);